=== modified file 'compat/compat_shared.h'
--- compat/compat_shared.h	2009-04-07 14:14:19 +0000
+++ compat/compat_shared.h	2009-04-20 12:52:26 +0000
@@ -210,4 +210,20 @@
 #endif
 
 
+/**
+ * gcc requires some special function formatting hints.
+ *
+ * gcc doesn't recognize the Windows native 64 bit formatting tags causing
+ * the compile fail, so we must disable the check on native Windows.
+ */
+#if __GNUC__ && !defined(_SQUID_MSWIN_)
+#define PRINTF_FORMAT_ARG1 __attribute__ ((format (printf, 1, 2)))
+#define PRINTF_FORMAT_ARG2 __attribute__ ((format (printf, 2, 3)))
+#define PRINTF_FORMAT_ARG3 __attribute__ ((format (printf, 3, 4)))
+#else
+#define PRINTF_FORMAT_ARG1
+#define PRINTF_FORMAT_ARG2
+#define PRINTF_FORMAT_ARG3
+#endif
+
 #endif /* _SQUID_COMPAT_SHARED_H */

=== modified file 'include/config.h'
--- include/config.h	2009-03-03 02:52:23 +0000
+++ include/config.h	2009-04-20 12:50:52 +0000
@@ -237,20 +237,6 @@
 #define squid_srandom srand
 #endif
 
-/* gcc doesn't recognize the Windows native 64 bit formatting tags causing
- * the compile fail, so we must disable the check on native Windows.
- */
-
-#if __GNUC__ && !defined(_SQUID_MSWIN_)
-#define PRINTF_FORMAT_ARG1 __attribute__ ((format (printf, 1, 2)))
-#define PRINTF_FORMAT_ARG2 __attribute__ ((format (printf, 2, 3)))
-#define PRINTF_FORMAT_ARG3 __attribute__ ((format (printf, 3, 4)))
-#else
-#define PRINTF_FORMAT_ARG1
-#define PRINTF_FORMAT_ARG2
-#define PRINTF_FORMAT_ARG3
-#endif
-
 /*
  * Determine if this is a leak check build or standard
  */

=== modified file 'include/fatal.h'
--- include/fatal.h	2009-02-15 13:01:35 +0000
+++ include/fatal.h	2009-04-20 12:53:08 +0000
@@ -1,8 +1,10 @@
+#ifndef SQUID_CONFIG_H
+#include "config.h"
+#endif
+
 #ifndef SQUID_FATAL_H
 #define SQUID_FATAL_H
 
-#include "config.h"
-
 SQUIDCEXTERN void fatal(const char *message);
 SQUIDCEXTERN void fatalf(const char *fmt,...) PRINTF_FORMAT_ARG1;
 SQUIDCEXTERN void fatal_dump(const char *message);


